<?php

namespace Drupal\orange_dam\Plugin\migrate\process;

use Drupal\migrate\MigrateException;
use Drupal\migrate\MigrateExecutableInterface;
use Drupal\migrate\Row;
use Drupal\node\NodeInterface;

/**
 * Alter the published state if the passed in field is empty.
 *
 * @MigrateProcessPlugin(
 *   id = "orange_dam_unpublish_on_empty"
 * )
 *
 * @code
 * status:
 *   plugin: orange_dam_unpublish_on_empty
 *   source: foo
 *   field: bar
 * @endcode
 */
class OrangeDamUnpublishOnEmpty extends OrangeDamProcessBase {

  /**
   * {@inheritdoc}
   */
  public function transform($value, MigrateExecutableInterface $migrateExecutable, Row $row, $destinationProperty): int {
    // Validate that we have the needed configuration.
    if (empty($this->configuration['field'])) {
      throw new MigrateException('Missing "field" configuration in the "orange_dam_unpublish_on_empty" process plugin.');
    }
    // If the field is empty, mark the item as unpublished.
    if (trim($row->get($this->configuration['field'])) === '') {
      return NodeInterface::NOT_PUBLISHED;
    }
    // Leave the value unaltered.
    return $value;
  }

}
